HashOrHeight

Enum HashOrHeight 

pub enum HashOrHeight {
    Hash(BlockHash),
    Height(u32),
}
Represents either a block hash or block height (integer)

This type is used in some Bitcoin RPC APIs where methods can accept either a block hash or a block height to identify a specific block.

Variants



Hash(BlockHash)

Block hash



Height(u32)

Block height as a non-negative integer

Implementations

Source

impl HashOrHeight

pub fn is_hash(&self) -> bool

Returns true if this represents a block hash

pub fn is_height(&self) -> bool

Returns true if this represents a block height

pub fn as_hash(&self) -> Option<&BlockHash>

Returns the block hash if this is a Hash variant, otherwise None

pub fn as_height(&self) -> Option<u32>

Returns the block height if this is a Height variant, otherwise None